@@ -9,7 +9,7 @@ import time
 from motordecalidad.rules import *
 
 
-print("Motor de Calidad Version Release 1.8.7")
+print("Motor de Calidad Version Release 1.9.1")
 
 # Main function, Invokes all the parameters from the json, Optionally filters, starts the rule validation
 # Writes and returns the summary of the validation 
@@ -487,18 +487,18 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                 column = rules[code].get(JsonParts.Fields)
                 if column[0] == "*" :
                     res = measuresCentralTendency(object, object.columns, spark)
-                    writeDf(res,rules[code].get(JsonParts.Output))
+                    writeDf(res,rules[code].get(JsonParts.Output),"estadisticas.csv")
                 else:
                     res = measuresCentralTendency(object, column,spark)
-                    writeDf(res,rules[code].get(JsonParts.Output))
+                    writeDf(res,rules[code].get(JsonParts.Output),"estadisticas.csv")
         else:
             pass
     if errorData.count() > Zero:
-        writeDf(errorData,error)
+        writeDf(errorData,error,"error.csv")
     try:
         if validData == "TRUE":
             finalData = object.join(errorData,on = Data.get(JsonParts.Fields), how = LeftAntiType)
-            writeDf(finalData,Data,rulesNumber)
+            writeDf(finalData,Data,rulesNumber,"data,csv")
     except:
         pass
     validationData:DataFrame = spark.createDataFrame(data = rulesData, schema = OutputDataFrameColumns)
@@ -510,7 +510,7 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
         year_widget = dbutils.widgets.get('year')
         month_widget = dbutils.widgets.get('month')
         day_widget = dbutils.widgets.get('day')
-        dataDateWidget = year_widget + month_widget + day_widget
+        dataDateWidget = year_widget +"-"+ month_widget +"-"+ day_widget
     except:
         dataDateWidget = dataDate
     try:
